@@ -1,25 +1,15 @@
 import platform as platform_
 import sys
 from datetime import datetime
+from functools import partial
 from pathlib import Path as LibPath
 from zipfile import ZipFile
 
 import requests
 import toml
-from click import (
-    Choice,
-    Path,
-    argument,
-    command,
-    get_app_dir,
-    option,
-    pass_context,
-    secho,
-)
+from click import (Choice, Path, argument, command, get_app_dir, option,
+                   pass_context, secho, style)
 from requests.exceptions import ConnectionError, HTTPError, Timeout
-from rich import print as print_rich
-from rich.console import Console
-from rich.markdown import Markdown
 
 try:
     from importlib.metadata import version
@@ -45,6 +35,9 @@ DEFAULT_CONFIG_DIR = LibPath(get_app_dir("tldr"))
 DEFAULT_CONFIG_FILE = DEFAULT_CONFIG_DIR / "config.toml"
 DEFAULT_CACHE_DIR = LibPath.home() / ".cache" / "tldr"
 
+info = partial(secho, bold=True, fg="green")
+warn = partial(secho, bold=True, fg="yellow")
+
 
 class PageCache:
     """PageCache intends to manage local cache data.
@@ -171,36 +164,77 @@ class PageFinder:
 class Formatter:
     """Formatter decides how pages (or other prompts) are displayed.
 
-    Now Formatter simply wraps `rich` utilities for markdown rendering,
-    which is likely to change for better output. Also styling params
-    will be exposed in the future.
+    Attributes:
+        buffer: Content will be split by lines and stored in this list
+          before any other operations.
+        start_with_new_line: Add extra new line in the begining.
+
+    Methods:
+        output: As a class method and should be the only interface to use
+          Formatter. Raw content will be processed, rendered and print in
+          order before the final result was output.
     """
 
-    def __init__(self, content, style=None):
-        self.content_orig = content
-        self.content = self.content_orig.replace("{{", "").replace("}}", "")
-        self.style = style
+    def __init__(
+        self, content, is_page=False, indent_spaces=0, start_with_new_line=False
+    ):
+        self.content = content
+        self.buffer = []
+        self.is_page = is_page
+        self.indent_spaces = indent_spaces
+        self.start_with_new_line = start_with_new_line
 
-    def output_markdown(self):
-        console = Console()
-        # FIXME: Syntax highlighting for inline code
-        md = Markdown(
-            self.content,
-            code_theme="",
-            inline_code_lexer="console",
-            inline_code_theme="monokai",
-        )
-        console.print(md, style=self.style)
-        # FIXME: Find a better way for end line gap
-        console.print()
+    def process_content(self):
+        for line in self.content.split("\n"):
+            line = line.strip()
+            if self.is_page:
+                for sym in ("{{", "}}", "`"):
+                    line = line.replace(sym, "")
+            self.buffer.append(line)
+
+    def render_text(self, **args):
+        rendered_lines = []
+        if not self.is_page:
+            rendered_lines = [style(line, **args) for line in self.buffer]
+        else:
+            for line in self.buffer:
+                if line == "":
+                    pass
+                elif line[0] == "#":
+                    line = style(line[2:], bold=True, fg="red")
+                elif line[0] == ">":
+                    line = line[2:].replace("<", "").replace(">", "")
+                    line = style(line, fg="yellow", underline=True)
+                elif line[0] == "-":
+                    line = style("\u2022" + line[1:], fg="green")
+                else:
+                    line = style("  " + line, fg="magenta")
+                rendered_lines.append(line)
+        self.buffer = rendered_lines
+
+    def print(self, value=""):
+        secho(f'{" "*self.indent_spaces}{value}')
 
     @classmethod
-    def output(cls, content, category=None, style=None):
-        formatter = cls(content, style=style)
-        if category == "markdown":
-            formatter.output_markdown()
-        else:
-            print_rich(formatter.content)
+    def output(
+        cls,
+        content,
+        indent_spaces=0,
+        is_page=False,
+        start_with_new_line=False,
+        **args,
+    ):
+        if not isinstance(content, str):
+            raise ValueError("Formatter only accept strings")
+        if not content:
+            return
+        formatter = cls(content, is_page, indent_spaces, start_with_new_line)
+        formatter.process_content()
+        formatter.render_text(**args)
+        if formatter.start_with_new_line:
+            formatter.print()
+        for line in formatter.buffer:
+            formatter.print(line)
 
 
 def guess_os():
@@ -216,8 +250,8 @@ def guess_os():
 def print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
         return
-    Formatter.output(f"tldr version {VERSION_CLI}")
-    Formatter.output(f"client specification version {VERSION_CLIENT_SPEC}")
+    info(f"tldr version {VERSION_CLI}")
+    info(f"client specification version {VERSION_CLIENT_SPEC}")
     ctx.exit()
 
 
@@ -235,15 +269,15 @@ def setup_config(ctx, param, value):
         config_file = DEFAULT_CONFIG_FILE
 
         if not config_file.exists():
-            secho("No config file found, setting it up...", fg="yellow")
+            warn("No config file found, setting it up...")
             config_dir.mkdir(parents=True, exist_ok=True)
             with open(config_file, "w") as f:
                 toml.dump(DEFAULT_CONFIG, f)
-            secho(f"Config file created: {config_file}", fg="yellow")
+            warn(f"Config file created: {config_file}")
             config = DEFAULT_CONFIG
     else:
         config_file = value
-        secho(f"Using config file from {config_file}", fg="yellow")
+        warn(f"Using config file from {config_file}")
 
     if not config:
         with open(config_file) as f:
@@ -292,7 +326,7 @@ def cli(ctx, config, command, platform, update):
     )
     if update:
         page_cache.update()
-        secho("Finish cache update.", fg="green", bold=True)
+        info("Finish cache update.")
 
     if not command:
         if not update:
@@ -318,10 +352,10 @@ def cli(ctx, config, command, platform, update):
         page_content = result.get("content")
 
     if page_content:
-        Formatter.output(page_content, category="markdown")
-    else:
-        Formatter.output("There is no available pages right now.")
         Formatter.output(
-            "Create an issue here: https://github.com/tldr-pages/tldr/issues"
+            page_content, indent_spaces=4, is_page=True, start_with_new_line=True
         )
+    else:
+        warn("There is no available pages right now.")
+        warn("You can create an issue via https://github.com/tldr-pages/tldr/issues.")
         sys.exit(1)
